@@ -12,16 +12,15 @@ import React, { useContext } from "react";
 import {
   Count,
   LayoutSwitcher,
-  Pagination,
   ResultsMultiLayout,
   Sort,
   ResultsList,
   ResultsGrid,
-  ResultsPerPage,
 } from "react-searchkit";
 import { Grid } from "semantic-ui-react";
 import { SearchConfigurationContext } from "./context";
 import { i18next } from "@translations/invenio_search_ui/i18next";
+import { InvenioSearchPagination } from "./InvenioSearchPagination";
 
 export const Results = ({ currentResultsState = {} }) => {
   const { total } = currentResultsState.data;
@@ -51,51 +50,7 @@ export const Results = ({ currentResultsState = {} }) => {
               )}
             </Grid.Column>
           </Grid.Row>
-          <Grid.Row verticalAlign="middle" floated="right">
-            <Grid.Column className="computer tablet only" width={4}></Grid.Column>
-            <Grid.Column
-              className="computer tablet only"
-              width={8}
-              textAlign="center"
-            >
-              <Pagination
-                options={{
-                  size: "mini",
-                  showFirst: false,
-                  showLast: false,
-                }}
-              />
-            </Grid.Column>
-            <Grid.Column className="mobile only" width={16} textAlign="center">
-              <Pagination
-                options={{
-                  boundaryRangeCount: 0,
-                  showFirst: false,
-                  showLast: false,
-                }}
-              />
-            </Grid.Column>
-            <Grid.Column
-              className="computer tablet only "
-              textAlign="right"
-              width={4}
-            >
-              <ResultsPerPage
-                values={paginationOptions.resultsPerPage}
-                label={(cmp) => <> {cmp} results per page</>}
-              />
-            </Grid.Column>
-            <Grid.Column
-              className="mobile only mt-10"
-              textAlign="center"
-              width={16}
-            >
-              <ResultsPerPage
-                values={paginationOptions.resultsPerPage}
-                label={(cmp) => <> {cmp} results per page</>}
-              />
-            </Grid.Column>
-          </Grid.Row>
+          <InvenioSearchPagination paginationOptions={paginationOptions} />
         </Grid>
       </Overridable>
     )
